This function creates a list of cutpoints for use with tsbart().

makeCutpoints(X, gridlen=10000)

Arguments

X

A matrix; the design matrix for the tsBART model. (Can use the output of makeModelMatrix, which expands categorical predictors to columns of indicators when creating design matrix.) Defaults to NULL.

gridlen

Length of grid for continuous predictors. Defaults to 10,000.

Value

cutpoints

A list of vectors, where each is a cutpoint for each covariate (column of design matrix X).

Examples

if (FALSE) { ## Create list of cutpoints. cuts <- makeCutpoints(X, gridlen=1000) }