R/KStest.R
makeModelMatrix.RdThis function creates a model matrix for use with tsbart().
makeModelMatrix(df)
| df | A data frame. Defaults to NULL. |
|---|
An overparameterized model matrix, where factor covariates are split into columns of indicators, with one column for each level, including the baseline level.
if (FALSE) { ## Create model matrix. x <- makeModelMatrix(mydf) }