makeCutpoints.RdThis function creates a list of cutpoints for use with tsbart().
makeCutpoints(X, gridlen=10000)
| X | A matrix; the design matrix for the tsBART model. (Can use the output of |
|---|---|
| gridlen | Length of grid for continuous predictors. Defaults to 10,000. |
A list of vectors, where each is a cutpoint for each covariate (column of design matrix X).
if (FALSE) { ## Create list of cutpoints. cuts <- makeCutpoints(X, gridlen=1000) }